Crate blue_build_recipe

Crate blue_build_recipe 

Structs

AkmodsInfo
AkmodsInfoBuilder
Use builder syntax to set the inputs and finish with build().
Module
ModuleBuilder
Use builder syntax to set the inputs and finish with build().
ModuleExt
ModuleExtBuilder
Use builder syntax to set the inputs and finish with build().
ModuleRequiredFields
ModuleRequiredFieldsBuilder
Use builder syntax to set the inputs and finish with build().
ModuleTypeVersion
RecipeV1
The build recipe.
RecipeV1Builder
Use builder syntax to set the inputs and finish with build().
Stage
Corresponds to a stage in a Containerfile
StageBuilder
Use builder syntax to set the inputs and finish with build().
StageRequiredFields
Contains the required fields for a stage.
StageRequiredFieldsBuilder
Use builder syntax to set the inputs and finish with build().
StagesExt
StagesExtBuilder
Use builder syntax to set the inputs and finish with build().

Enums

MaybeVersion
Recipe

Traits

FromFileList
RecipeGetters