Structs
- Akmods
Info - Akmods
Info Builder - Use builder syntax to set the inputs and finish with
build(). - Module
- Module
Builder - Use builder syntax to set the inputs and finish with
build(). - Module
Ext - Module
ExtBuilder - Use builder syntax to set the inputs and finish with
build(). - Module
Required Fields - Module
Required Fields Builder - Use builder syntax to set the inputs and finish with
build(). - Module
Type Version - Recipe
V1 - The build recipe.
- Recipe
V1Builder - Use builder syntax to set the inputs and finish with
build(). - Stage
- Corresponds to a stage in a Containerfile
- Stage
Builder - Use builder syntax to set the inputs and finish with
build(). - Stage
Required Fields - Contains the required fields for a stage.
- Stage
Required Fields Builder - Use builder syntax to set the inputs and finish with
build(). - Stages
Ext - Stages
ExtBuilder - Use builder syntax to set the inputs and finish with
build().